@@ -36,7 +36,7 @@ cols=c(colSpeed,colForce,colPower); lty=rep(1,3)
 #way A. passing options to a file
 getOptionsFromFile <- function(optionsFile) {
 	optionsCon <- file(optionsFile, 'r')
-	options=readLines(optionsCon,n=17)
+	options=readLines(optionsCon,n=18)
 	close(optionsCon)
 	return (options)
 }
@@ -55,8 +55,8 @@ options=getOptionsFromFile(optionsFile);
 
 print(options)
 
-OutputData2=options[4] #currently used to display status
-OperatingSystem=options[17]
+OutputData2=options[4] #currently used to display processing feedback
+OperatingSystem=options[18]
 
 write("(1/5) Starting R", OutputData2)
 
@@ -158,8 +158,13 @@ findCurves <- function(rawdata, eccon, min_height, draw, title) {
 #based on findPics2BySpeed
 #only used in eccon "c"
 #if this changes, change also in python capture file
-reduceCurveBySpeed <- function(eccon, row, startT, rawdata, smoothing) {
+reduceCurveBySpeed <- function(eccon, row, startT, rawdata, smoothingOneEC, smoothingOneC) {
 	a=rawdata
+
+	smoothing = 0
+	if(eccon == "c")
+		smoothing = smoothingOneC
+
 	speed <- smooth.spline( 1:length(a), a, spar=smoothing) 
 	b=extrema(speed$y)
 
@@ -181,73 +186,105 @@ reduceCurveBySpeed <- function(eccon, row, startT, rawdata, smoothing) {
 	return(startT+x.ini)
 }
 
-#go here with every single jump
-kinematicsF <- function(a, mass, smoothingOne, g, eccon, analysisOptions) {
+findECPhases <- function(a,speed) {
+	b=extrema(speed)
+	print(b)
+	#In all the extrema minindex values, search which range (row) has the min values,
+	#and in this range search last value
+	print("searchMinSpeedEnd")
+	searchMinSpeedEnd = max(which(speed == min(speed)))
+	print(searchMinSpeedEnd)
+	#In all the extrema maxindex values, search which range (row) has the max values,
+	#and in this range search first value
+	print("searchMaxSpeedIni")
+	searchMaxSpeedIni = min(which(speed == max(speed)))
+	print(searchMaxSpeedIni)
+	#find the cross between both
+	print("b-Cross")
+	print(b$cross[,1])
+	print("search min cross: crossMinRow")
+	crossMinRow=which(b$cross[,1] > searchMinSpeedEnd & b$cross[,1] < searchMaxSpeedIni)
+	print(crossMinRow)
+			
+	#if (length(crossMinRow) > 0) {
+	#	print(crossMinRow)
+	#} else {
+	#	propulsiveEnd = length(a)
+	#	errorSearching = TRUE
+	#}
+	
+	eccentric = 0
+	isometric = 0
+	concentric = 0
+				
+	isometricUse = TRUE
+	if(isometricUse) {
+		eccentric=1:min(b$cross[crossMinRow,1])
+		isometric=c(min(b$cross[crossMinRow,1]), max(b$cross[crossMinRow,2]))
+		concentric=max(b$cross[crossMinRow,2]):length(a)
+	} else {
+		eccentric=1:mean(b$cross[crossMinRow,1])
+		isometric=c(mean(b$cross[crossMinRow,1]), mean(b$cross[crossMinRow,2]))
+		concentric=mean(b$cross[crossMinRow,2]):length(a)
+	}
+	return(list(
+		eccentric=eccentric,
+		isometric=isometric,
+		concentric=concentric))
+}
+
+findPropulsiveEnd <- function(accel, concentric) {
+	if(length(which(accel[concentric]<=-g)) > 0) 
+		propulsiveEnd = min(concentric) + min(which(accel[concentric] <= -g))
+	else
+		propulsiveEnd = max(concentric)
+	
+return (propulsiveEnd)
+}
+
+#go here with every single curve
+#eccon="c" one time each curve
+#eccon="ec" one time each curve
+#eccon="ecS" means ecSeparated. two times each curve: one for "e", one for "c"
+kinematicsF <- function(a, mass, smoothingOneEC, smoothingOneC, g, eccon, analysisOptions) {
 	print("length unique x in spline")
 	print(length(unique(1:length(a))))
 
-	speed <- smooth.spline( 1:length(a), a, spar=smoothingOne)
+	smoothing = 0
+	if(eccon == "c")
+		smoothing = smoothingOneC
+	else
+		smoothing = smoothingOneEC
+
+	speed <- smooth.spline( 1:length(a), a, spar=smoothing)
 	accel <- predict( speed, deriv=1 )
 	#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
 	accel$y <- accel$y * 1000 
 	errorSearching = FALSE
 
-	eccentric = 0
+	concentric = 0
+	propulsiveEnd = 0
 
-	#search propulsiveEnds
+print("at kinematicsF eccon==")
+print(eccon)
+
+	#search propulsiveEnd
 	if(analysisOptions == "p") {
 		if(eccon=="c") {
 			concentric=1:length(a)
-		} else {	#"ec", "ecS"
-			b=extrema(speed$y)
-			print(b)
-			#In all the extrema minindex values, search which range (row) has the min values,
-			#and in this range search last value
-			print("searchMinSpeedEnd")
-			searchMinSpeedEnd = max(which(speed$y == min(speed$y)))
-			print(searchMinSpeedEnd)
-			#In all the extrema maxindex values, search which range (row) has the max values,
-			#and in this range search first value
-			print("searchMaxSpeedIni")
-			searchMaxSpeedIni = min(which(speed$y == max(speed$y)))
-			print(searchMaxSpeedIni)
-			#find the cross between both
-			print("b-Cross")
-			print(b$cross[,1])
-			print("search min cross: crossMinRow")
-			crossMinRow=which(b$cross[,1] > searchMinSpeedEnd & b$cross[,1] < searchMaxSpeedIni)
-			
-			print("AT KINEMATICSF")
-			print(crossMinRow)
-
-			if (length(crossMinRow) > 0) {
-				print(crossMinRow)
-
-				isometricUse = TRUE
-				if(isometricUse) {
-					eccentric=1:min(b$cross[crossMinRow,1])
-					concentric=max(b$cross[crossMinRow,2]):length(a)
-				} else {
-					eccentric=1:mean(b$cross[crossMinRow,1])
-					concentric=mean(b$cross[crossMinRow,2]):length(a)
-				}
-			} else {
-				propulsiveEnds = length(a)
-				errorSearching = TRUE
-			}
-		}
-
-		if(! errorSearching) {
-			#propulsive phase ends when accel is -9.8
-			if(length(which(accel$y[concentric]<=-g)) > 0 & analysisOptions == "p") {
-				propulsiveEnds = max(eccentric) + min(which(accel$y[concentric]<=-g))
-			} else {
-				propulsiveEnds = max(concentric)
-			}
+			propulsiveEnd = findPropulsiveEnd(accel$y,concentric)
+		} else if(eccon=="ec") {
+			phases=findECPhases(a,speed$y)
+			eccentric = phases$eccentric
+			isometric = phases$isometric
+			concentric = phases$concentric
+			propulsiveEnd = findPropulsiveEnd(accel$y,concentric)
+		} else if(eccon=="e") {
+			#not eccon="e" because not propulsive calculations on eccentric
+		} else { #ecS
+print("WARNING ECS\n\n\n\n\n")
 		}
 	}
-	#end of search propulsiveEnds
-
 
 #	force <- mass*accel$y
 #	if(isJump)
@@ -255,9 +292,9 @@ kinematicsF <- function(a, mass, smoothingOne, g, eccon, analysisOptions) {
 
 	power <- force*speed$y
 
-	if(analysisOptions == "p")
-		return(list(speedy=speed$y[1:propulsiveEnds], accely=accel$y[1:propulsiveEnds], 
-			    force=force[1:propulsiveEnds], power=power[1:propulsiveEnds], mass=mass))
+	if( analysisOptions == "p" && ( eccon== "c" || eccon == "ec" ) )
+		return(list(speedy=speed$y[1:propulsiveEnd], accely=accel$y[1:propulsiveEnd], 
+			    force=force[1:propulsiveEnd], power=power[1:propulsiveEnd], mass=mass))
 	else
 		return(list(speedy=speed$y, accely=accel$y, force=force, power=power, mass=mass))
 }
@@ -286,19 +323,18 @@ powerBars <- function(eccon, kinematics) {
 			  kinematics$mass,meanForce,maxForce))
 }
 
-kinematicRanges <- function(singleFile,rawdata,curves,mass,smoothingOne,g,eccon,analysisOptions) {
+kinematicRanges <- function(singleFile,rawdata,curves,mass,smoothingOneEC,smoothingOneC,g,eccon,analysisOptions) {
 	n=length(curves[,1])
 	maxSpeedy=0;maxForce=0;maxPower=0
 	myEccon = eccon
 	for(i in 1:n) { 
 		myMass = mass
-		mySmoothingOne = smoothingOne
+		#mySmoothingOne = smoothingOne
 		if(! singleFile) {
 			myMass = curves[i,5]
-			mySmoothingOne = curves[i,6]
-			myEccon = curves[i,8]
+			myEccon = curves[i,7]
 		}
-		kn=kinematicsF(rawdata[curves[i,1]:curves[i,2]],myMass,mySmoothingOne,g,myEccon,analysisOptions)
+		kn=kinematicsF(rawdata[curves[i,1]:curves[i,2]],myMass,smoothingOneEC,smoothingOneC,g,myEccon,analysisOptions)
 		if(max(abs(kn$speedy)) > maxSpeedy)
 			maxSpeedy = max(abs(kn$speedy))
 		if(max(abs(kn$force)) > maxForce)
@@ -314,7 +350,7 @@ kinematicRanges <- function(singleFile,rawdata,curves,mass,smoothingOne,g,eccon,
 
 
 paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highlight,
-	startX, startH, smoothing, mass, title, subtitle, draw, showLabels, marShrink, showAxes, legend,
+	startX, startH, smoothingOneEC, smoothingOneC, mass, title, subtitle, draw, showLabels, marShrink, showAxes, legend,
 	Analysis, AnalysisOptions, ExercisePercentBodyWeight 
 	) {
 
@@ -322,6 +358,12 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	meanSpeedC = 0
 	meanPowerE = 0
 	meanPowerC = 0
+	
+	smoothing = 0
+	if(eccon == "c")
+		smoothing = smoothingOneC
+	else
+		smoothing = smoothingOneEC
 
 	#eccons ec and ecS is the same here (only show one curve)
 	#receive data as cumulative sum
@@ -414,8 +456,9 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	#	segments(x0=b$maxindex,y0=0,x1=b$maxindex,y1=speed$y[b$maxindex],col=cols[1])
 
 	#declare variables:
-	concentric=0
 	eccentric=0
+	isometric=0
+	concentric=0
 	if(eccon=="c") {
 		concentric=1:length(a)
 	} else {	#"ec", "ecS"
@@ -444,12 +487,12 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 		isometricUse = TRUE
 		if(isometricUse) {
 			eccentric=1:min(b$cross[crossMinRow,1])
-			concentric=max(b$cross[crossMinRow,2]):length(a)
 			isometric=c(min(b$cross[crossMinRow,1]), max(b$cross[crossMinRow,2]))
+			concentric=max(b$cross[crossMinRow,2]):length(a)
 		} else {
 			eccentric=1:mean(b$cross[crossMinRow,1])
-			concentric=mean(b$cross[crossMinRow,2]):length(a)
 			isometric=c(mean(b$cross[crossMinRow,1]), mean(b$cross[crossMinRow,2]))
+			concentric=mean(b$cross[crossMinRow,2]):length(a)
 		}
 
 		if(draw) {
@@ -480,24 +523,24 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	if(draw) {
 		#propulsive phase ends when accel is -9.8
 		if(length(which(accel$y[concentric]<=-g)) > 0 & AnalysisOptions == "p") {
-			propulsiveEnds = max(eccentric) + min(which(accel$y[concentric]<=-g))
+			propulsiveEnd = min(concentric) + min(which(accel$y[concentric]<=-g))
 		} else {
-			propulsiveEnds = max(concentric)
+			propulsiveEnd = max(concentric)
 		}
 
 		ylim=c(-max(abs(range(accel$y))),max(abs(range(accel$y))))	 #put 0 in the middle
 
 		meanSpeedC = mean(speed$y[min(concentric):max(concentric)])
 		if(AnalysisOptions == "p") {
-			meanSpeedC = mean(speed$y[min(concentric):propulsiveEnds])
+			meanSpeedC = mean(speed$y[min(concentric):propulsiveEnd])
 		}
 
 		if(eccon == "c") {
-			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnds,y1=meanSpeedC,col=cols[1],code=3)
+			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnd,y1=meanSpeedC,col=cols[1],code=3)
 		} else {
 			meanSpeedE = mean(speed$y[min(eccentric):max(eccentric)])
 			arrows(x0=min(eccentric),y0=meanSpeedE,x1=max(eccentric),y1=meanSpeedE,col=cols[1],code=3)
-			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnds,y1=meanSpeedC,col=cols[1],code=3)
+			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnd,y1=meanSpeedC,col=cols[1],code=3)
 		}
 
 		
@@ -533,10 +576,12 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 			plot(startX:length(accel$y),accel$y[startX:length(accel$y)],type="l",
 			     xlim=c(1,length(a)),ylim=ylim,xlab="",ylab="",col="darkblue",lty=2,lwd=3,axes=F)
 			
-		#propulsive stuff
-		abline(h=-g,lty=3,col="magenta")
-		abline(v=propulsiveEnds,lty=3,col="magenta") 
-		points(propulsiveEnds, -g, col="magenta")
+		if(AnalysisOptions == "p") {
+			#propulsive stuff
+			abline(h=-g,lty=3,col="magenta")
+			abline(v=propulsiveEnd,lty=3,col="magenta") 
+			points(propulsiveEnd, -g, col="magenta")
+		}
 		
 		if(showAxes)
 			axis(4, col="magenta", lty=lty[1], line=2, lwd=1, padj=-.5)
@@ -614,15 +659,15 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 
 		meanPowerC = mean(power[min(concentric):max(concentric)])
 		if(AnalysisOptions == "p") {
-			meanPowerC = mean(power[min(concentric):propulsiveEnds])
+			meanPowerC = mean(power[min(concentric):propulsiveEnd])
 		}
 
 		if(eccon == "c") {
-			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnds,y1=meanPowerC,col=cols[3],code=3)
+			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnd,y1=meanPowerC,col=cols[3],code=3)
 		} else {
 			meanPowerE = mean(power[min(eccentric):max(eccentric)])
 			arrows(x0=min(eccentric),y0=meanPowerE,x1=max(eccentric),y1=meanPowerE,col=cols[3],code=3)
-			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnds,y1=meanPowerC,col=cols[3],code=3)
+			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnd,y1=meanPowerC,col=cols[3],code=3)
 		}
 
 		if(showAxes) {
@@ -681,6 +726,16 @@ paint <- function(rawdata, eccon, xmin, xmax, yrange, knRanges, superpose, highl
 	}
 }
 
+textBox <- function(x,y,text,frontCol,bgCol,xpad=.1,ypad=1){
+
+	w=strwidth(text)+xpad*strwidth(text)
+	h=strheight(text)+ypad*strheight(text)
+
+	rect(x-w/2,y-h/2,x+w/2,y+h/2,col=bgCol, border=NA)
+	text(x,y,text,col=frontCol)
+} 
+
+
 paintPowerPeakPowerBars <- function(singleFile, title, paf, myEccons, Eccon, height, n) {
 	pafColors=c("tomato1","tomato4",topo.colors(10)[3])
 	myNums = rownames(paf)
@@ -754,8 +809,15 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, myEccons, Eccon, hei
 			 bp[2,min(which(load == i))],mean(height[which(load == i)]),
 			 bp[2,max(which(load == i))],mean(height[which(load == i)]),
 			 lty=1,col="green")
-		text(x=mean(bp[2,which(load == i)]),y=mean(height[which(load == i)]),
-		     labels=round(mean(height[which(load == i)]),1),adj=c(.5,0),cex=.9)
+
+		myLabel = round(mean(height[which(load == i)]),1)
+
+		text(x=mean(bp[2,which(load == i)]),
+		     y=mean(height[which(load == i)]),
+		     labels=myLabel,adj=c(.5,0),cex=.9,col="darkgreen")
+		#textBox(mean(bp[2,which(load == i)]),
+		#	mean(height[which(load == i)]),
+		#	myLabel, "green", "white", ypad=1)
 	}
 	
 	#plot legend on top exactly out
@@ -787,6 +849,19 @@ findPosInPaf <- function(var, option) {
 	return(pos)
 }
 
+addUnits <- function (var) {
+	if(var == "Speed")
+		return ("Speed (m/s)")
+	else if(var == "Power")
+		return ("Power (W)")
+	else if(var == "Load") #or Mass
+		return ("Load (Kg)")
+	else if(var == "Force")
+		return ("Force (N)")
+
+	return(var)
+}
+
 #option: mean or max
 paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, singleFile, Eccon, seriesName) {
 	x = (paf[,findPosInPaf(varX, option)])
@@ -798,6 +873,9 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 	colBalls = NULL
 	bgBalls = NULL
 
+	varX = addUnits(varX)
+	varY = addUnits(varY)
+
 	#if only one series
 	if(length(unique(seriesName)) == 1) {
 		myNums = rownames(paf)
@@ -846,14 +924,15 @@ paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, single
 		#in x axis move a little every series to right in order to compare
 		seqX = seq(0,length(unique(seriesName))-1,by=1)-(length(unique(seriesName))-1)/2
 
+		plot(x,y, xlab=varX, ylab="", type="n", axes=F)
 		for(i in 1:length(seriesName)) {
 			thisSerie = which(seriesName == unique(seriesName)[i])
 			colBalls[thisSerie] = uniqueColors[i]
 			#in x axis move a little every series to right in order to compare
-			x[thisSerie] = x[thisSerie] + seqX[i]
+			x[thisSerie] = x[thisSerie] + (seqX[i]/5)
 		}
 		
-		plot(x,y, xlab=varX, ylab="", pch=19, col=colBalls, cex=1.8, axes=F)
+		points(x,y, pch=19, col=colBalls, cex=1.8)
 		
 		for(i in 1:length(seriesName)) {
 			thisSerie = which(seriesName == unique(seriesName)[i])
@@ -997,20 +1076,22 @@ doProcess <- function(options) {
 	File=options[1]
 	OutputGraph=options[2]
 	OutputData1=options[3]
-	OutputData2=options[4] #currently used to display status
+	OutputData2=options[4] #currently used to display processing feedback
 	MinHeight=as.numeric(options[5])*10 #from cm to mm
 	ExercisePercentBodyWeight=as.numeric(options[6])	#was isJump=as.logical(options[6])
 	Mass=as.numeric(options[7])
 	Eccon=options[8]
 	Analysis=options[9]	#in cross comes as "cross.Force.Speed.mean"
 	AnalysisOptions=options[10]	#p: propulsive
-	SmoothingOne=options[11]
-	Jump=options[12]
-	Width=as.numeric(options[13])
-	Height=as.numeric(options[14])
-	DecimalSeparator=options[15]
-	Title=options[16]
-	OperatingSystem=options[17]
+	SmoothingOneEC=options[11]
+	SmoothingOneC=options[12]
+	Jump=options[13]
+	Width=as.numeric(options[14])
+	Height=as.numeric(options[15])
+	DecimalSeparator=options[16]
+	Title=options[17]
+	OperatingSystem=options[18]	#if this changes, change it also at start of this R file
+	#important, if this grows, change the readLines value on getOptionsFromFile
 
 	print(File)
 	print(OutputGraph)
@@ -1110,7 +1191,7 @@ doProcess <- function(options) {
 				startH[(i+newLines)] = 0
 				exerciseName[(i+newLines)] = as.vector(inputMultiData$exerciseName[i])
 				mass[(i+newLines)] = inputMultiData$mass[i]
-				smooth[(i+newLines)] = inputMultiData$smoothingOne[i]
+				#smooth[(i+newLines)] = inputMultiData$smoothingOne[i] #unused since 1.3.7
 				dateTime[(i+newLines)] = as.vector(inputMultiData$dateTime[i])
 
 				curvesHeight[(i+newLines)] = sum(dataTempPhase)
@@ -1148,10 +1229,10 @@ doProcess <- function(options) {
 		#then a column id is created when there's only on row, but it is not created there's more than one.
 		#solution:
 		if(length(id)==1) {
-			curves = data.frame(start,end,startH,exerciseName,mass,smooth,
+			curves = data.frame(start,end,startH,exerciseName,mass,
 					    dateTime,myEccon,seriesName,stringsAsFactors=F,row.names=id)
 		} else {
-			curves = data.frame(id,start,end,startH,exerciseName,mass,smooth,
+			curves = data.frame(id,start,end,startH,exerciseName,mass,
 					    dateTime,myEccon,seriesName,stringsAsFactors=F,row.names=1)
 		}
 
@@ -1180,8 +1261,8 @@ doProcess <- function(options) {
 		quitIfNoData(n, curves, OutputData1)
 
 		for(i in 1:n) { 
-			curves[i,1]=reduceCurveBySpeed(Eccon, i, curves[i,1],
-						       rawdata[curves[i,1]:curves[i,2]], SmoothingOne)
+			curves[i,1]=reduceCurveBySpeed(Eccon, i, curves[i,1], rawdata[curves[i,1]:curves[i,2]], 
+						       SmoothingOneEC, SmoothingOneC)
 		}
 		if(curvesPlot) {
 			#/10 mm -> cm
@@ -1210,20 +1291,19 @@ doProcess <- function(options) {
 	if(Analysis=="single") {
 		if(Jump>0) {
 			myMass = Mass
-			mySmoothingOne = SmoothingOne
+			#mySmoothingOne = SmoothingOne
 			myEccon = Eccon
 			myStart = curves[Jump,1]
 			myEnd = curves[Jump,2]
 			if(! singleFile) {
 				myMass = curves[Jump,5]
-				mySmoothingOne = curves[Jump,6]
-				myEccon = curves[Jump,8]
+				#mySmoothingOne = curves[Jump,6]
+				myEccon = curves[Jump,7]
 			}
 			myCurveStr = paste("curve=", Jump, ", ", myMass, "Kg", sep="")
 			paint(rawdata, myEccon, myStart, myEnd,"undefined","undefined",FALSE,FALSE,
-			      1,curves[Jump,3],mySmoothingOne,myMass,
-			      paste(Title, " ", Analysis, " ", myEccon, " ", myCurveStr,
-				    " (smoothing: ",mySmoothingOne,")",sep=""),
+			      1,curves[Jump,3],SmoothingOneEC,SmoothingOneC,myMass,
+			      paste(Title, " ", Analysis, " ", myEccon, " ", myCurveStr, sep=""),
 			      "", #subtitle
 			      TRUE,	#draw
 			      TRUE,	#showLabels
@@ -1243,16 +1323,17 @@ doProcess <- function(options) {
 		#yrange=c(min(a),max(a))
 		yrange=find.yrange(singleFile, rawdata, curves)
 
-		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOne,g,Eccon,AnalysisOptions)
+		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOneEC,SmoothingOneC,
+					 g,Eccon,AnalysisOptions)
 
 		for(i in 1:n) {
 			myMass = Mass
-			mySmoothingOne = SmoothingOne
+			#mySmoothingOne = SmoothingOne
 			myEccon = Eccon
 			if(! singleFile) {
 				myMass = curves[i,5]
-				mySmoothingOne = curves[i,6]
-				myEccon = curves[i,8]
+				#mySmoothingOne = curves[i,6]
+				myEccon = curves[i,7]
 			}
 
 			myTitle = ""
@@ -1262,7 +1343,7 @@ doProcess <- function(options) {
 			mySubtitle = paste("curve=", rownames(curves)[i], ", ", myMass, "Kg", sep="")
 
 			paint(rawdata, myEccon, curves[i,1],curves[i,2],yrange,knRanges,FALSE,FALSE,
-			      1,curves[i,3],mySmoothingOne,myMass,myTitle,mySubtitle,
+			      1,curves[i,3],SmoothingOneEC,SmoothingOneC,myMass,myTitle,mySubtitle,
 			      TRUE,	#draw
 			      FALSE,	#showLabels
 			      TRUE,	#marShrink
@@ -1285,7 +1366,7 @@ doProcess <- function(options) {
 		#yrange=c(min(a),max(a))
 		yrange=find.yrange(singleFile, rawdata,curves)
 
-		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOne,g,Eccon,AnalysisOptions)
+		knRanges=kinematicRanges(singleFile,rawdata,curves,Mass,SmoothingOneEC,SmoothingOneC,g,Eccon,AnalysisOptions)
 		for(i in 1:n) {
 			#in superpose all jumps end at max height
 			#start can change, some are longer than other
@@ -1298,7 +1379,7 @@ doProcess <- function(options) {
 				myTitle = paste(titleType,Jump);
 
 			paint(rawdata, Eccon, curves[i,2]-wide,curves[i,2],yrange,knRanges,TRUE,(i==Jump),
-			      startX,curves[i,3],SmoothingOne,Mass,myTitle,"",
+			      startX,curves[i,3],SmoothingOneEC,SmoothingOneC,Mass,myTitle,"",
 			      TRUE,	#draw
 			      TRUE,	#showLabels
 			      FALSE,	#marShrink
@@ -1331,12 +1412,12 @@ doProcess <- function(options) {
 		discardingCurves = FALSE
 		for(i in 1:n) { 
 			myMass = Mass
-			mySmoothingOne = SmoothingOne
+			#mySmoothingOne = SmoothingOne
 			myEccon = Eccon
 			if(! singleFile) {
 				myMass = curves[i,5]
-				mySmoothingOne = curves[i,6]
-				myEccon = curves[i,8]
+				#mySmoothingOne = curves[i,6]
+				myEccon = curves[i,7]
 
 				#only use concentric data	
 				if(Analysis == "1RMBadillo2010" & myEccon == "e") {
@@ -1354,9 +1435,19 @@ doProcess <- function(options) {
 
 			print("i:")
 			print(i)
+
+			#if ecS go kinematics first time with "e" and second with "c"
+			myEcconKn = myEccon
+			if(myEccon=="ecS") {
+			       if(i%%2 == 1)
+				       myEcconKn = "e"
+			       else
+				       myEcconKn = "c"
+			}
 			paf=rbind(paf,(powerBars(myEccon,
 						 kinematicsF(rawdata[curves[i,1]:curves[i,2]], 
-							     myMass, mySmoothingOne, g, myEccon, AnalysisOptions))))
+							     myMass, SmoothingOneEC,SmoothingOneC, 
+							     g, myEcconKn, AnalysisOptions))))
 		}
 
 		#on 1RMBadillo discard curves "e", because paf has this curves discarded
@@ -1365,23 +1456,25 @@ doProcess <- function(options) {
 			curves = curves[-discardedCurves,]
 
 		rownames(paf)=rownames(curves)
-		print("----------------------------")
+		print("--------CURVES--------------")
+		print(curves)
+		print("----------PAF---------------")
 		print(paf)
 
 		if(Analysis == "powerBars") {
 			if(! singleFile) 
 				paintPowerPeakPowerBars(singleFile, Title, paf, 
-							curves[,8], Eccon,	 	#myEccon, Eccon
+							curves[,7], Eccon,	 	#myEccon, Eccon
 							curvesHeight, n)			#height
 			else 
 				paintPowerPeakPowerBars(singleFile, Title, paf, 
-							curves[,8], Eccon,		#myEccon, Eccon
+							curves[,7], Eccon,		#myEccon, Eccon
 							rawdata.cumsum[curves[,2]]-curves[,3], n) #height
 		}
 		else if(analysisCross[1] == "cross") {
 			mySeries = "1"
 			if(! singleFile)
-				mySeries = curves[,9]
+				mySeries = curves[,8]
 
 			if(analysisCross[2] == "Speed,Power") {
 				par(mar=c(5,4,4,5))
@@ -1415,7 +1508,7 @@ doProcess <- function(options) {
 					curvesHeight = curvesHeight[-discardedCurves]
 
 				paf=cbind(
-					  curves[,9],		#seriesName
+					  curves[,8],		#seriesName
 					  curves[,4],		#exerciseName
 					  curves[,5],		#mass
 					  curves[,1],		
@@ -1452,7 +1545,8 @@ doProcess <- function(options) {
 		namesNums=paste(namesNums, units)
 
 		for(i in 1:curvesNum) { 
-			kn = kinematicsF (rawdata[curves[i,1]:curves[i,2]], Mass, SmoothingOne, g, Eccon, AnalysisOptions)
+			kn = kinematicsF (rawdata[curves[i,1]:curves[i,2]], Mass, 
+					  SmoothingOneEC, SmoothingOneC, g, Eccon, AnalysisOptions)
 
 			#fill with NAs in order to have the same length
 			col1 = rawdata[curves[i,1]:curves[i,2]]
