@@ -64,7 +64,7 @@ public class Constants
 	public const string SubtractionBetweenTests = "Subtraction between tests";
 
 	//tests types (dont' use character '-' will be used multimedia file names)
-	public enum TestTypes { JUMP, JUMP_RJ, RUN, RUN_I, RT, PULSE, MULTICHRONOPIC }
+	public enum TestTypes { JUMP, JUMP_RJ, RUN, RUN_I, RT, PULSE, MULTICHRONOPIC, ENCODER }
 	public static string JumpSimpleName = "Jump simple";
 	public static string JumpReactiveName = "Jump reactive";
 	public static string RunSimpleName = "Run simple";
@@ -173,7 +173,7 @@ public class Constants
 	public static string TakeOffWeightName = "TakeOffWeight"; //translate (take off?)
 
 
-	public static string SpreadsheetString = "\n\n" + Catalog.GetString("When import from your spreadsheet (OpenOffice, R, MS Excel, ...)\nremember the separator character is semicolon: <b>;</b>");
+	public static string SpreadsheetString = "\n\n" + Catalog.GetString("When import from your spreadsheet (OpenOffice, R, MS Excel, ...)\nremember the separator character is semicolon <b>;</b>, or comma <b>,</b>.");
 
 /*	OLD, check this
 	public static string PotencyLewisCMJFormula = Catalog.GetString("Peak Power")+ " CMJ (Lewis) " +
@@ -537,7 +537,7 @@ public class Constants
 
 	//heightmetric contains 2 spins
 	public enum GenericWindowShow {
-		ENTRY, ENTRY2, ENTRY3, SPININT, SPINDOUBLE, HEIGHTMETRIC, COMBOALLNONESELECTED, TEXTVIEW, TREEVIEW
+		ENTRY, ENTRY2, ENTRY3, SPININT, SPINDOUBLE, HEIGHTMETRIC, COMBO, COMBOALLNONESELECTED, TEXTVIEW, TREEVIEW
 	}
 	
 	public const string PrefVersionAvailable = "versionAvailable";
@@ -567,6 +567,8 @@ public class Constants
 	public static string RunStartInitialSpeedYes = Catalog.GetString("Running start. Started with initial speed.");
 	public static string RunStartInitialSpeedNo = Catalog.GetString("Standing start. Started without initial speed.");
 	
+	public static string CameraNotFound = Catalog.GetString("Sorry, no cameras found.");
+	
 	public enum BellModes {
 		JUMPS, RUNS, ENCODER
 	}
@@ -594,6 +596,8 @@ public class Constants
 	//if this name changes, change it in encoder/graph.R
 	public static string EncoderGraphInputMulti = "chronojump-encoder-graph-input-multi.csv"; 
 
+	public enum EncoderCheckFileOp { ANALYZE_EXPORT_ALL_CURVES, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_TABLE}
+
 	public enum DoubleContact {
 		FIRST, AVERAGE, LAST
 	}
