@@ -261,7 +261,7 @@ public class EditEventWindow
 
 		//also remove new line for old descriptions that used a textview
 		string temp = Util.RemoveTildeAndColonAndDot(myEvent.Description);
-		entry_description.Text = Util.RemoveNewLine(temp);
+		entry_description.Text = Util.RemoveNewLine(temp, true);
 
 		createComboEventType(myEvent);
 		
@@ -315,6 +315,7 @@ public class EditEventWindow
 			Gtk.Window d = new Gtk.Window(Catalog.GetString("Playing video"));
 			d.Add(player);
 			d.Modal = true;
+			d.SetDefaultSize(500,400);
 			d.ShowAll();
 			d.DeleteEvent += delegate(object sender, DeleteEventArgs e) {player.Close(); player.Dispose();};
 			player.Play(); 
