@@ -43,6 +43,14 @@ public class GenericWindow
 
 	[Widget] Gtk.SpinButton spin_double;
 	[Widget] Gtk.Box hbox_height_metric;
+
+	//generic combo
+	[Widget] Gtk.Box hbox_combo_full_line;
+	[Widget] Gtk.Label hbox_combo_label;
+	[Widget] Gtk.Box hbox_combo;
+	[Widget] Gtk.ComboBox combo;
+	[Widget] Gtk.Button hbox_combo_button;
+	
 	[Widget] Gtk.Box hbox_all_none_selected;
 	[Widget] Gtk.Box hbox_combo_all_none_selected;
 	[Widget] Gtk.ComboBox combo_all_none_selected;
@@ -55,6 +63,10 @@ public class GenericWindow
 	[Widget] Gtk.Button button_accept;
 	[Widget] Gtk.Button button_cancel;
 	
+	//treeview fake buttons
+	[Widget] Gtk.Button button_row_edit;
+	[Widget] Gtk.Button button_row_delete;
+	
 	[Widget] Gtk.Box hbox_entry2;
 	[Widget] Gtk.Label label_entry2;
 	[Widget] Gtk.Entry entry2;
@@ -75,6 +87,7 @@ public class GenericWindow
 	//used when we don't need to read data, 
 	//and we want to ensure next window will be created at needed size
 	public bool DestroyOnAccept;
+	public int TreeviewSelectedUniqueID;
 
 	public GenericWindow ()
 	{
@@ -139,6 +152,7 @@ public class GenericWindow
 		hbox_spin_int.Hide();
 		spin_double.Hide();
 		hbox_height_metric.Hide();
+		hbox_combo_full_line.Hide();
 		hbox_all_none_selected.Hide();
 		hbox_combo_all_none_selected.Hide();
 		scrolled_window_textview.Hide();
@@ -176,10 +190,16 @@ public class GenericWindow
 		else if(stuff == Constants.GenericWindowShow.HEIGHTMETRIC) {
 			hbox_height_metric.Show();
 		}
+		else if(stuff == Constants.GenericWindowShow.COMBO) {
+			/*
+			hbox_combo.Show();
+			combo.Show();
+			*/
+		}
 		else if(stuff == Constants.GenericWindowShow.COMBOALLNONESELECTED) {
-			//createComboAllNoneSelected();
+			//createComboCheckBoxes();
 			//combo_all_none_selected.Active = 
-			//	UtilGtk.ComboMakeActive(comboAllNoneSelectedOptions, Catalog.GetString("Selected"));
+			//	UtilGtk.ComboMakeActive(comboCheckBoxesOptions, Catalog.GetString("Selected"));
 			hbox_combo_all_none_selected.Show();
 			hbox_all_none_selected.Show();
 		}
@@ -205,6 +225,13 @@ public class GenericWindow
 			spin_double.Show();
 		else if(stuff == Constants.GenericWindowShow.HEIGHTMETRIC)
 			hbox_height_metric.Show();
+		else if(stuff == Constants.GenericWindowShow.COMBO) {
+			//do later, we need to create them first
+			/*
+			hbox_combo.Show();
+			combo.Show();
+			*/
+		}
 		else if(stuff == Constants.GenericWindowShow.TEXTVIEW)
 			scrolled_window_textview.Show();
 		else //if(stuff == Constants.GenericWindowShow.TREEVIEW)
@@ -226,15 +253,41 @@ public class GenericWindow
 		spin_int.SetRange(min, max);
 	}
 	
-	protected static string [] comboAllNoneSelectedOptions = {
+	public void SetComboValues(string [] values, string current) {
+		combo = ComboBox.NewText ();
+		UtilGtk.ComboUpdate(combo, values, "");
+		
+		hbox_combo.PackStart(combo, true, true, 0);
+		hbox_combo.ShowAll();
+		combo.Sensitive = true;
+			
+		combo.Active = UtilGtk.ComboMakeActive(values, current);
+	}
+	public void SetComboLabel(string l) {
+		hbox_combo_label.Text = l;
+	}
+	public void ShowCombo(bool show) {
+		hbox_combo_full_line.Visible = show;
+	}
+
+	
+	protected string [] comboCheckBoxesOptions = {
 		Catalog.GetString("All"),
 		Catalog.GetString("None"),
+		Catalog.GetString("Invert"),
 		Catalog.GetString("Selected"),
 	};
+	
+	//this search in first column
+	//private string [] addOptionsToComboCheckBoxesOptions(string [] newOptions) {
+	public void AddOptionsToComboCheckBoxesOptions(ArrayList newOptions) {
+		comboCheckBoxesOptions = Util.AddArrayString( comboCheckBoxesOptions, 
+				Util.ArrayListToString(newOptions) );
+	}
 
-	public void CreateComboAllNoneSelected() {
+	public void CreateComboCheckBoxes() {
 		combo_all_none_selected = ComboBox.NewText ();
-		UtilGtk.ComboUpdate(combo_all_none_selected, comboAllNoneSelectedOptions, "");
+		UtilGtk.ComboUpdate(combo_all_none_selected, comboCheckBoxesOptions, "");
 		
 		//combo_all_none_selected.DisableActivate ();
 		combo_all_none_selected.Changed += new EventHandler (on_combo_all_none_selected_changed);
@@ -244,7 +297,7 @@ public class GenericWindow
 		combo_all_none_selected.Sensitive = true;
 			
 		combo_all_none_selected.Active = 
-			UtilGtk.ComboMakeActive(comboAllNoneSelectedOptions, Catalog.GetString("Selected"));
+			UtilGtk.ComboMakeActive(comboCheckBoxesOptions, Catalog.GetString("Selected"));
 	}
 	
 	protected void on_combo_all_none_selected_changed(object o, EventArgs args) {
@@ -267,12 +320,30 @@ public class GenericWindow
 			if(selected == Catalog.GetString("All")) {
 				do {
 					if(! Util.FoundInArrayList(nonSensitiveRows, i))
-						store.SetValue (iter, 0, true);
+						store.SetValue (iter, 1, true);
+					i++;
+				} while ( store.IterNext(ref iter) );
+			} else if(selected == Catalog.GetString("Invert")) {
+				bool val;
+				do {
+					if(! Util.FoundInArrayList(nonSensitiveRows, i)) {
+						val = (bool) store.GetValue (iter, 1);
+						store.SetValue (iter, 1, !val);
+					}
 					i++;
 				} while ( store.IterNext(ref iter) );
 			} else if(selected == Catalog.GetString("None")) {
 				do {
-					store.SetValue (iter, 0, false);
+					store.SetValue (iter, 1, false);
+				} while ( store.IterNext(ref iter) );
+			} else {	//encoderExercises
+				do {
+					if(selected == (string) store.GetValue (iter, 3) &&
+							! Util.FoundInArrayList(nonSensitiveRows, i))
+						store.SetValue (iter, 1, true);
+					else
+						store.SetValue (iter, 1, false);
+					i++;
 				} while ( store.IterNext(ref iter) );
 			}
 		}
@@ -291,7 +362,7 @@ public class GenericWindow
 	
 	//data is an ArrayList of strings[], each string [] is a row, each of its strings is a column
 	public void SetTreeview(string [] columnsString, bool addCheckbox, 
-			ArrayList data, ArrayList myNonSensitiveRows) 
+			ArrayList data, ArrayList myNonSensitiveRows, bool contextMenu) 
 	{
 		//adjust window to be bigger
 		generic_window.Resizable = true;
@@ -303,14 +374,18 @@ public class GenericWindow
 		prepareHeaders(columnsString, addCheckbox);
 
 		nonSensitiveRows = myNonSensitiveRows;
-		
-		if(addCheckbox)
-			createCheckboxes(treeview);
-
+	
+Log.WriteLine("aaaaaaaaaaaaaaaa1");	
 		foreach (string [] line in data) 
 			store.AppendValues (line);
+Log.WriteLine("aaaaaaaaaaaaaaaa2");	
 
 		treeview.CursorChanged += on_treeview_cursor_changed; 
+		if(contextMenu) {
+			button_row_edit = new Gtk.Button();
+			button_row_delete = new Gtk.Button();
+			treeview.ButtonReleaseEvent += on_treeview_button_release_event;
+		}
 	}
 	
 	public void MarkActiveCurves(string [] checkboxes) 
@@ -321,22 +396,19 @@ public class GenericWindow
 		if(okIter) {
 			do {
 				if(checkboxes[count++] == "active")
-					store.SetValue (iter, 0, true);
+					store.SetValue (iter, 1, true);
 			} while ( store.IterNext(ref iter) );
 		}
 	}
 	
 	private TreeStore getStore (int columns, bool addCheckbox)
 	{
-		if(addCheckbox)
-			columns++;
-
 		//prepares the TreeStore for required columns
 		Type [] types = new Type [columns];
 
 		for (int i=0; i < columns; i++) {
-			if(addCheckbox && i == 0)
-				types[0] = typeof (bool);
+			if(addCheckbox && i == 1)
+				types[1] = typeof (bool);
 			else
 				types[i] = typeof (string);
 		}
@@ -351,10 +423,14 @@ public class GenericWindow
 		int i=0;
 		bool visible = false;
 		foreach(string myCol in columnsString) {
-			UtilGtk.CreateCols(treeview, store, myCol, i++, visible);
-			if(i == 1)	//first columns: ID, is hidden
-				store.SetSortFunc (0, UtilGtk.IdColumnCompare);
+			if(addCheckbox && i == 1)
+				createCheckboxes(treeview);
+			else
+				UtilGtk.CreateCols(treeview, store, myCol, i, visible);
+//			if(i == 1)	//first columns: ID, is hidden
+//				store.SetSortFunc (0, UtilGtk.IdColumnCompare);
 			visible = true;
+			i++;
 		}
 	}
 	
@@ -373,6 +449,8 @@ public class GenericWindow
 			SetButtonAcceptSensitive(true);
 		else
 			SetButtonAcceptSensitive(false);
+	
+		ShowCombo(false);
 	}
 	
 	public int TreeviewSelectedRowID() {
@@ -392,12 +470,13 @@ public class GenericWindow
 		crt.Active = true;
 		crt.Toggled += ItemToggled;
 
-		TreeViewColumn column = new TreeViewColumn ("", crt, "active", 0);
+		TreeViewColumn column = new TreeViewColumn ("", crt, "active", 1);
 		column.Clickable = true;
-		tv.InsertColumn (column, 0);
+		tv.AppendColumn (column);
+		
 	}
 	
-	//if column == 0 returns checkboxes column. If is 1 returns column 1...
+	//if column == 1 returns checkboxes column. If is 2 returns column 2...
 	public string [] GetCheckboxesStatus(int column, bool onlyActive) 
 	{
 		//to store active or inactive status of curves
@@ -408,19 +487,19 @@ public class GenericWindow
 		bool okIter = store.GetIterFirst(out iter);
 		if(okIter) {
 			do {
-				if(column == 0) {
-					if((bool) store.GetValue (iter, 0))
+				if(column == 1) {
+					if((bool) store.GetValue (iter, 1))
 						checkboxes[count++] = "active";
 					else
 						checkboxes[count++] = "inactive";
 				}
 				else
-					if((bool) store.GetValue (iter, 0) || ! onlyActive)
+					if((bool) store.GetValue (iter, 1) || ! onlyActive)
 						checkboxes[count++] = ((string) store.GetValue (iter, column));
 				
 			} while ( store.IterNext(ref iter) );
 		}
-		if(column == 0)
+		if(column == 1)
 			return checkboxes;
 		else {
 			string [] checkboxesWithoutGaps = new string[count];
@@ -431,7 +510,7 @@ public class GenericWindow
 	}
 
 	protected void ItemToggled(object o, ToggledArgs args) {
-		int column = 0;
+		int column = 1;
 		TreeIter iter;
 		if (store.GetIter (out iter, new TreePath(args.Path))) 
 		{
@@ -445,14 +524,71 @@ public class GenericWindow
 
 				combo_all_none_selected.Active =
 					UtilGtk.ComboMakeActive(
-							comboAllNoneSelectedOptions, Catalog.GetString("Selected"));
+							comboCheckBoxesOptions, Catalog.GetString("Selected"));
 
 				//check if there are rows checked for having sensitive or not
 				//buttonRecuperateChangeSensitiveness();
 			}
 		}
 	}
-	
+
+	private void on_treeview_button_release_event (object o, ButtonReleaseEventArgs args) {
+		//TreeviewSelectedUniqueID = -1;
+
+                Gdk.EventButton e = args.Event;
+                Gtk.TreeView tv = (Gtk.TreeView) o;
+		TreeModel model = treeview.Model;
+		if (e.Button == 3) {
+			TreeIter iter = new TreeIter();
+			//TreeModel myModel = tv.Model;
+			if (tv.Selection.GetSelected (out model, out iter)) {
+/*
+Log.WriteLine((string) store.GetValue (iter, 0));
+//Log.WriteLine((string) store.GetValue (iter, 1));
+Log.WriteLine((string) store.GetValue (iter, 2));
+Log.WriteLine((string) store.GetValue (iter, 3));
+*/
+				//TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
+				TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
+				treeviewContextMenu();
+			}
+		}
+		ShowCombo(false);
+	}
+
+	private void treeviewContextMenu() {
+		Menu myMenu = new Menu ();
+		Gtk.MenuItem myItem;
+
+		myItem = new MenuItem ( Catalog.GetString("Edit selected") );
+		myItem.Activated += on_edit_selected_clicked;
+		myMenu.Attach( myItem, 0, 1, 0, 1 );
+
+
+		myItem = new MenuItem ( Catalog.GetString("Delete selected") );
+		myItem.Activated += on_delete_selected_clicked;
+		myMenu.Attach( myItem, 0, 1, 1, 2 );
+
+		myMenu.Popup();
+		myMenu.ShowAll();
+	}
+
+	private void on_edit_selected_clicked (object o, EventArgs args) {
+		button_row_edit.Click();
+	}
+
+	public void RemoveSelectedRow () {
+		store = UtilGtk.RemoveRow(treeview, store);
+	}
+
+	private void on_delete_selected_clicked (object o, EventArgs args) {
+		//remove selected row from treeview
+		store = UtilGtk.RemoveRow(treeview, store);
+
+		//activate button to manage on gui/encoder.cs in order to delete from SQL
+		button_row_delete.Click();
+	}
+
 	
 	public void SetButtonAcceptLabel(string str) {
 		button_accept.Label=str;
@@ -462,6 +598,10 @@ public class GenericWindow
 		button_accept.Sensitive=show;
 	}
 	
+	public void SetButtonCancelLabel(string str) {
+		button_cancel.Label=str;
+	}
+	
 	public void ShowButtonCancel(bool show) {
 		button_cancel.Visible = show;
 	}
@@ -500,6 +640,21 @@ public class GenericWindow
 		get { return button_accept; }
 	}
 		
+	public Button Button_row_edit {
+		set { button_row_edit = value; }
+		get { return button_row_edit; }
+	}
+		
+	public Button Button_row_edit_apply {
+		set { hbox_combo_button = value; }
+		get { return hbox_combo_button; }
+	}
+		
+	public Button Button_row_delete {
+		set { button_row_delete = value; }
+		get { return button_row_delete; }
+	}
+	
 	public string EntrySelected {
 		set { entry.Text = value; }
 		get { return entry.Text.ToString(); }
@@ -539,6 +694,10 @@ public class GenericWindow
 	public string TextviewSelected {
 		get { return Util.RemoveTab(textview.Buffer.Text); }
 	}
+
+	public string GetComboSelected {
+		get { return UtilGtk.ComboGetActive(combo); }
+	}
 	
 
 	~GenericWindow() {}
