@@ -52,10 +52,10 @@ class SqliteEncoder : Sqlite
 			"url TEXT, " +
 			"time INT, " +
 			"minHeight INT, " +
-			"smooth FLOAT, " +  
+			"smooth FLOAT, " +  	//unused. since 1.3.7 is on preferences
 			"description TEXT, " +
 			"future1 TEXT, " +	//works as status: "active", "inactive"
-			"future2 TEXT, " +
+			"future2 TEXT, " +	//URL of video of signals
 			"future3 TEXT )";
 		dbcmd.ExecuteNonQuery();
 	}
@@ -116,7 +116,7 @@ class SqliteEncoder : Sqlite
 				"', url = '" + es.url +
 				"', time = " + es.time +
 				", minHeight = " + es.minHeight +
-				", smooth = " + Util.ConvertToPoint(es.smooth) +
+				", smooth = " + Util.ConvertToPoint(es.smooth) +	//unused. in 1.3.7 is on preferences
 				", description = '" + es.description + 
 				"', future1 = '" + es.future1 + 
 				"', future2 = '" + es.future2 + 
@@ -192,7 +192,7 @@ class SqliteEncoder : Sqlite
 					reader[9].ToString(),			//url
 					Convert.ToInt32(reader[10].ToString()),	//time
 					Convert.ToInt32(reader[11].ToString()),	//minHeight
-					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[12].ToString())), //smooth
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[12].ToString())), //smooth UNUSED
 					reader[13].ToString(),			//description
 					reader[14].ToString(),			//future1
 					reader[15].ToString(),			//future2
@@ -317,7 +317,7 @@ class SqliteEncoder : Sqlite
 		string [] iniEncoderExercises = {
 			//name:percentBodyWeight:ressistance:description
 			"Bench press:0:weight bar:", 
-			"Squat:75:weight bar:", 
+			"Squat:100:weight bar:", 
 			"Jump:100:none:",
 			"Free:0::"	
 		};
@@ -328,6 +328,25 @@ class SqliteEncoder : Sqlite
 		}
 	}
 
+	public static void UpdateExercise(bool dbconOpened, string name, int percentBodyWeight, 
+			string ressistance, string description)
+	{
+		if(! dbconOpened)
+			dbcon.Open();
+
+		dbcmd.CommandText = "UPDATE " + Constants.EncoderExerciseTable + " SET " +
+				" percentBodyWeight = " + percentBodyWeight +
+				", ressistance = '" + ressistance +
+				"', description = '" + description +
+				"' WHERE name = '" + name + "'" ;
+
+		Log.WriteLine(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		if(! dbconOpened)
+			dbcon.Close();
+	}
+	
 	//if uniqueID != -1, returns an especific EncoderExercise that can be read like this	
 	//EncoderExercise ex = (EncoderExercise) SqliteEncoder.SelectEncoderExercises(eSQL.exerciseID)[0];
 	public static ArrayList SelectEncoderExercises(bool dbconOpened, int uniqueID, bool onlyNames) 
