@@ -72,7 +72,7 @@ class Sqlite
 	 * Important, change this if there's any update to database
 	 * Important2: if database version get numbers higher than 1, check if the comparisons with currentVersion works ok
 	 */
-	static string lastChronojumpDatabaseVersion = "0.89";
+	static string lastChronojumpDatabaseVersion = "0.92";
 
 	public Sqlite() {
 	}
@@ -220,7 +220,7 @@ class Sqlite
 	{
 		Log.WriteLine(connectionString);
 
-		string applicationDataDir = Util.GetApplicationDataDir();
+		string applicationDataDir = UtilAll.GetApplicationDataDir();
 
 		if(!Directory.Exists(applicationDataDir)) {
 			Log.WriteLine("creating dir 1...");
@@ -365,7 +365,7 @@ class Sqlite
 		//string sqlite3Str = "";
 		string extension = "";
 		try {
-			if(Util.IsWindows()) {
+			if(UtilAll.IsWindows()) {
 				myPath = Constants.UtilProgramsWindows;
 				extension = Constants.ExtensionProgramsWindows;
 				sqliteStr = "sqlite.exe";
@@ -1216,6 +1216,41 @@ class Sqlite
 
 				currentVersion = "0.89";
 			}
+			if(currentVersion == "0.89") {
+				dbcon.Open();
+	
+				SqlitePreferences.Insert("encoderPropulsive", "True");
+				SqlitePreferences.Insert("encoderSmoothEccCon", "0.6");
+				SqlitePreferences.Insert("encoderSmoothCon", "0.7");
+				Log.WriteLine("Preferences added propulsive and encoder smooth");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.90", true); 
+				dbcon.Close();
+
+				currentVersion = "0.90";
+			}
+			if(currentVersion == "0.90") {
+				dbcon.Open();
+				
+				SqliteEncoder.UpdateExercise(true, "Squat", 100, "weight bar", "");	
+				Log.WriteLine("Encoder Squat 75% -> 100%");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.91", true); 
+				dbcon.Close();
+
+				currentVersion = "0.91";
+			}
+			if(currentVersion == "0.91") {
+				dbcon.Open();
+				
+				SqlitePreferences.Insert("videoDevice", "0");
+				Log.WriteLine("Added videoDevice to preferences");
+				
+				SqlitePreferences.Update ("databaseVersion", "0.92", true); 
+				dbcon.Close();
+
+				currentVersion = "0.92";
+			}
 		}
 
 		//if changes are made here, remember to change also in CreateTables()
@@ -1237,7 +1272,7 @@ class Sqlite
 		if(myPort == "0") {
 			//if doesn't exist (for any reason, like old database)
 			dbcon.Open();
-			if(Util.IsWindows() || creatingBlankDatabase)
+			if(UtilAll.IsWindows() || creatingBlankDatabase)
 				SqlitePreferences.Insert ("chronopicPort", Constants.ChronopicDefaultPortWindows);
 			else
 				SqlitePreferences.Insert ("chronopicPort", Constants.ChronopicDefaultPortLinux);
@@ -1354,6 +1389,9 @@ class Sqlite
 		SqliteCountry.initialize();
 		
 		//changes [from - to - desc]
+		//0.91 - 0.92 Converted DB to 0.92 Added videoDevice to preferences
+		//0.90 - 0.91 Converted DB to 0.91 Encoder Squat 75% -> 100%
+		//0.89 - 0.90 Converted DB to 0.90 Preferences added propulsive and encoder smooth
 		//0.88 - 0.89 Converted DB to 0.89 Added encoder exercise: Free
 		//0.87 - 0.88 Converted DB to 0.88 Deleted fake RSA test and added known RSA tests
 		//0.86 - 0.87 Converted DB to 0.87 Added run speed start preferences on sqlite
@@ -1711,8 +1749,8 @@ class Sqlite
 
 		foreach(int personID in myArray) {
 			//if person is not in other sessions, delete it from DB
-			if(! SqlitePersonSession.PersonExistsInPS(personID))
-				Delete(Constants.PersonTable, personID);
+			if(! SqlitePersonSession.PersonExistsInPS(true, personID))
+				Delete(true, Constants.PersonTable, personID);
 		}
 	}
 				
@@ -2112,14 +2150,18 @@ Console.WriteLine("5" + tableName);
 		return myReturn;
 	}
 
-	public static void Delete(string tableName, int uniqueID)
+	public static void Delete(bool dbconOpened, string tableName, int uniqueID)
 	{
-		dbcon.Open();
+		if( ! dbconOpened)
+			dbcon.Open();
+
 		dbcmd.CommandText = "Delete FROM " + tableName +
 			" WHERE uniqueID == " + uniqueID.ToString();
 		Log.WriteLine(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
-		dbcon.Close();
+		
+		if( ! dbconOpened)
+			dbcon.Close();
 	}
 
 
