@@ -39,7 +39,7 @@ class SqlitePreferences : Sqlite
 	{
 		Insert ("databaseVersion", databaseVersion); 
 			
-		if(Util.IsWindows() || creatingBlankDatabase)
+		if(UtilAll.IsWindows() || creatingBlankDatabase)
 			Insert ("chronopicPort", Constants.ChronopicDefaultPortWindows);
 		else
 			Insert ("chronopicPort", Constants.ChronopicDefaultPortLinux);
@@ -70,6 +70,11 @@ class SqlitePreferences : Sqlite
 		Insert ("machineID", machineID);
 		
 		Insert ("multimediaStorage", Constants.MultimediaStorage.BYSESSION.ToString());
+		
+		Insert ("encoderPropulsive", "True");
+		Insert ("encoderSmoothEccCon", "0.6");
+		Insert ("encoderSmoothCon", "0.7");
+		Insert ("videoDevice", "0"); //first
 	}
 
 	public static void Insert(string myName, string myValue)
