@@ -103,16 +103,6 @@ public class Util
 			return Math.Round(Convert.ToDouble(time), prefsDigitsNumber).ToString();
 	}
 
-	//if passed (number=1, digits=4)
-	//takes 1 and returns "0001" 
-	public static string DigitsCreate (int number, int digits)
-	{
-		string str = number.ToString();
-		while(str.Length < digits)
-			str = "0" + str;
-		return str;
-	}
-	
 	public static double GetMax (string values)
 	{
 		string [] myStringFull = values.Split(new char[] {'='});
@@ -303,10 +293,13 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 
-	public static string RemoveNewLine(string myString) 
+	public static string RemoveNewLine(string myString, bool changeBySpace) 
 	{
 		StringBuilder myStringBuilder = new StringBuilder(myString);
-		myStringBuilder.Replace("\n", " ");
+		if(changeBySpace)
+			myStringBuilder.Replace("\n", " ");
+		else
+			myStringBuilder.Replace("\n", "");
 		return myStringBuilder.ToString();
 	}
 
@@ -465,6 +458,18 @@ public class Util
 				final[count++] = str;
 		return final;
 	}
+
+	public static string [] DeleteStringAtPosition(string [] initial, int pos) {
+		string [] final = new String [initial.Length -1];
+		int count = 0;
+		foreach(string str in initial) {
+			if(count != pos)
+				final[count] = str;
+			count ++;
+		}
+
+		return final;
+	}
 	
 	
 	//called from jumpRj.Write() and from interval
@@ -688,25 +693,6 @@ public class Util
 		return (myInt % 2 == 0); //check if it's even (in spanish "par")
 	}
 
-	//Adapted from Mono. A developer's notebook. p 244
-	
-	//this is used in chronojump for working with the ports,
-	//in chronojump we compile now for Linux with Mono and for Windows with .NET
-	//it should be something like IsDotNet()
-	public static bool IsWindows() {
-		string os = GetOS();
-		if(os.ToUpper().StartsWith("WIN"))
-			return true;
-		else 
-			return false;
-	}
-	
-	public static string GetOS() {
-		OperatingSystem os = Environment.OSVersion;
-		string osString =  string.Format("{0}, {1}", os.Platform, os.Version);
-		return osString;
-	}
-	
 	public static string GetReallyOldDatabaseDir() {
 		return Environment.GetEnvironmentVariable("HOME")+ Path.DirectorySeparatorChar + ".chronojump";
 	}
@@ -719,13 +705,7 @@ public class Util
 		
 		return ".." + Path.DirectorySeparatorChar + ".." + Path.DirectorySeparatorChar + "database";
 	}
-	
-	public static string GetApplicationDataDir() {
-		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump");
-	}
-	
+
 	public static string GetDatabaseDir() {
 		//fixing:
 		//http://lists.ximian.com/pipermail/mono-list/2008-November/040480.html
@@ -824,16 +804,19 @@ public class Util
 			return Constants.ExtensionPhoto;
 	}
 			
-	public static bool MoveTempVideo(int sessionID, Constants.TestTypes type, int uniqueID) {
+	public static bool CopyTempVideo(int sessionID, Constants.TestTypes type, int uniqueID) {
 		string origin = GetVideoTempFileName();
 		string destination = GetVideoFileName(sessionID, type, uniqueID);
-		if(File.Exists(origin) && ! File.Exists(destination)) {
+		if(File.Exists(origin)) {
 			CreateVideoSessionDirIfNeeded(sessionID);
+			/*
+			 * no more move it, just copy it, because maybe is still being recorded
 			try {
 				File.Move(origin, destination);
 			} catch {
-				File.Copy(origin, destination);
-			}
+			*/
+				File.Copy(origin, destination, true); //can be overwritten
+			//}
 			return true;
 		} else
 			return false;
@@ -959,7 +942,7 @@ public class Util
 	
 	
 	private static string getEncoderScriptCapture() {
-		if(IsWindows())
+		if(UtilAll.IsWindows())
 			return System.IO.Path.Combine(GetPrefixDir(), 
 				"bin" + Path.DirectorySeparatorChar + "encoder", Constants.EncoderScriptCaptureWindows);
 		else
@@ -1038,6 +1021,17 @@ public class Util
 		return false;
 	}
 	
+	public static bool FileMove(string path, string filenameOrigin, string filenameDestination) {
+		try {
+			File.Move(
+					path + Path.DirectorySeparatorChar + filenameOrigin, 
+					path + Path.DirectorySeparatorChar + filenameDestination
+					);
+			return true;
+		} catch {}
+		return false;
+	}
+	
 	public static bool FileExists(string fileName){
 		return File.Exists(fileName);
 	}
@@ -1073,7 +1067,7 @@ public class Util
 		if (File.Exists(outputFile))
 			File.Delete(outputFile);
  
-		if (IsWindows())
+		if (UtilAll.IsWindows())
 			rBin=System.IO.Path.Combine(GetPrefixDir(), "bin/R.exe");
 
 		pinfo = new ProcessStartInfo();
@@ -1114,7 +1108,7 @@ public class Util
 		on linux we execute python and call to the py file
 		also on windows we need the full path to find R
 		*/
-		if (IsWindows()) {
+		if (UtilAll.IsWindows()) {
 			pBin=getEncoderScriptCapture();
 			pinfo.Arguments = title + " " + es.OutputData1 + " " + es.Ep.ToString1() + " " + port 
 				+ " " + changeSpaceToSpaceMark(
@@ -1162,7 +1156,7 @@ public class Util
 			
 		pBin="Rscript";
 		//pBin="R";
-		if (IsWindows()) {
+		if (UtilAll.IsWindows()) {
 			//on Windows we need the \"str\" to call without problems in path with spaces
 			pBin = "\"" + System.IO.Path.Combine(GetPrefixDir(), "bin" + Path.DirectorySeparatorChar + "Rscript.exe") + "\"";
 			Log.WriteLine("pBin:" + pBin);
@@ -1187,7 +1181,7 @@ public class Util
 		writer.Flush();
 		((IDisposable)writer).Dispose();
 		
-		if (IsWindows()) {
+		if (UtilAll.IsWindows()) {
 			//On win32 R understands backlash as an escape character and 
 			//a file path uses Unix-like path separator '/'		
 			optionsFile = optionsFile.Replace("\\","/");
@@ -1435,7 +1429,7 @@ public class Util
 
 	public static string GetImagePath(bool mini) {
 		string returnString = "";
-		if (Util.IsWindows()) {
+		if (UtilAll.IsWindows()) {
 			if (mini) {
 				returnString = Constants.ImagesMiniWindows;
 			} else {
@@ -1452,7 +1446,7 @@ public class Util
 	}
 		
 	public static string GetGladePath() {
-		if (Util.IsWindows())
+		if (UtilAll.IsWindows())
 			return Constants.GladeWindows;
 		else
 			return Constants.GladeLinux;
@@ -1573,11 +1567,17 @@ public class Util
 		return array;
 	}
 
-	public static string AddCsvIfNeeded(string myFile)
+	public static string AddCsvIfNeeded(string myFile) {
+		return addExtensionIfNeeded(myFile, ".csv");
+	}
+	public static string AddPngIfNeeded(string myFile) {
+		return addExtensionIfNeeded(myFile, ".png");
+	}
+	private static string addExtensionIfNeeded(string myFile, string extension)
 	{
 		int posOfDot = myFile.LastIndexOf('.');
 		if (posOfDot == -1) 
-			myFile += ".csv";
+			myFile += extension;
 		
 		return myFile;
 	}
@@ -1670,39 +1670,10 @@ public class Util
 		return myString.Trim('-');
 	}
 */
-	
-	public static string DetectPortsLinux(bool formatting) {
-		string startStr = "";
-		string midStr = "\n";
-		string endStr = "";
-		if(formatting) {
-			startStr = "<i>";
-			midStr = "\t";
-			endStr = "</i>";
-		}
-		string detected = "";
-		string [] usbSerial = Directory.GetFiles("/dev/", "ttyUSB*");
-		if(usbSerial.Length > 0) {
-			detected += Constants.FoundUSBSerialPortsString + " " + usbSerial.Length + "\n" + startStr;
-			foreach(string myPort in usbSerial)
-				detected += midStr + myPort;
-			detected += endStr;
-		} 
-		/*
-		   else {
-			detected += Constants.NotFoundUSBSerialPortsString + "\n";
-			string [] serial = Directory.GetFiles("/dev/", "ttyS*");
-			detected += Constants.FoundSerialPortsString + " " + serial.Length + "\n" + startStr;
-			foreach(string myPort in serial)
-				detected += midStr + myPort;
-			detected += endStr;
-		}
-		*/
-		return detected;
-	}
+
 
 	public static string GetDefaultPort() {
-		if(Util.IsWindows())
+		if(UtilAll.IsWindows())
 			return Constants.ChronopicDefaultPortWindows;
 		else
 			return Constants.ChronopicDefaultPortLinux;
