@@ -20,6 +20,7 @@
 
 using System;
 using System.Text; //StringBuilder
+using System.Collections; //ArrayList
 using Gtk;
 using Gdk;
 
@@ -27,59 +28,13 @@ using Gdk;
 //only Gtk related methods (not used bu the server) this is the differnece with Util
 public class UtilGtk
 {
-	/* howto find nice colors
-	 * open R
-	 * > colors()
-	 * if you like lightblue2 and red2 then:
-	 * > col2rgb(colors()[401])
-	 * > col2rgb(colors()[554])
+
+	/*
+	 *
+	 * COMBO
+	 *
 	 */
-	public static Gdk.Color WHITE = new Gdk.Color(0xff,0xff,0xff);
-	public static Gdk.Color BLACK = new Gdk.Color(0x00,0x00,0x00);
-	public static Gdk.Color BLUE = new Gdk.Color(0x6c,0x77,0xab);
-	public static Gdk.Color BLUE_CLEAR = new Gdk.Color(0xa0,0xa7,0xca);
-	
-	public static Gdk.Color RED_PLOTS = new Gdk.Color(238,0,0);
-	public static Gdk.Color LIGHT_BLUE_PLOTS = new Gdk.Color(178,223,238);
-	public static Gdk.Color BLUE_PLOTS = new Gdk.Color(0,0,238);
-	
-	public static void ResizeIfNeeded(Gtk.Window win) {
-		int winX, winY;
-		win.GetSize(out winX, out winY);
-		int maxY = ScreenHeightFitted(true);
-		if(winY > maxY)
-			win.Resize(winX, maxY);
-	}
 
-	//(takes care)? of menu bar
-	public static int ScreenHeightFitted(bool fit) {
-		if(fit)
-			return ScreenHeight() -25;
-		else
-			return ScreenHeight();
-	}
-	
-	private static int ScreenHeight() {
-		//libmono-cairo2.0-cil
-		return Gdk.Display.Default.GetScreen(0).Height;
-	}
-	
-	public static int WidgetWidth(Gtk.Widget w) {
-		return w.Allocation.Width;
-	}
-	public static int WidgetHeight(Gtk.Widget w) {
-		return w.Allocation.Height;
-	}
-
-	public static void IconWindow(Gtk.Window myWindow) {
-		Gdk.Pixbuf chronojumpIcon = new Gdk.Pixbuf (null, Constants.FileNameIcon);
-            	myWindow.Icon = chronojumpIcon;
-	}
-
-	public static void IconWindowGraph(Gtk.Window myWindow) {
-		Gdk.Pixbuf chronojumpIcon = new Gdk.Pixbuf (null, Constants.FileNameIconGraph);
-            	myWindow.Icon = chronojumpIcon;
-	}
 
 	public static string ComboGetActive(ComboBox myCombo) {
 		TreeIter iter;
@@ -184,6 +139,20 @@ public class UtilGtk
 		myCombo.AppendText (myData);
 	}
 
+	public static void ComboPackShowAndSensitive (Gtk.Box box, Gtk.ComboBox combo) {
+		box.PackStart(combo, true, true, 0);
+		box.ShowAll();
+		combo.Sensitive = true;
+	}
+	
+
+	/*
+	 *
+	 * TREEVIEW
+	 *
+	 */
+
+
 	public static void CreateCols (Gtk.TreeView tv, Gtk.TreeStore store, 
 			string name, int verticalPos, bool visible) {
 		Gtk.TreeViewColumn myCol = new Gtk.TreeViewColumn (name, new CellRendererText(), "text", verticalPos);
@@ -230,47 +199,86 @@ public class UtilGtk
 		
 		return (val1-val2);
 	}
+	
+	public static Gtk.TreeStore RemoveRow (Gtk.TreeView tv, Gtk.TreeStore store) {
+		TreeModel model;
+		TreeIter iter1;
 
-	public static void ComboPackShowAndSensitive (Gtk.Box box, Gtk.ComboBox combo) {
-		box.PackStart(combo, true, true, 0);
-		box.ShowAll();
-		combo.Sensitive = true;
-	}
-	
-
-	public static void ColorsMenuLabel(Gtk.Label l) {
-		l.ModifyFg(StateType.Active, WHITE);
-		l.ModifyFg(StateType.Normal, BLACK);
-	}
-	
-	public static void ColorsTestLabel(Gtk.Label l) {
-		l.ModifyFg(StateType.Active, WHITE);
-	}
-	
-	public static void ColorsRadio(Gtk.RadioButton r) {
-		r.ModifyBg(StateType.Normal, WHITE);
-		r.ModifyBg(StateType.Active, BLUE);
-		r.ModifyBg(StateType.Prelight, BLUE_CLEAR);
-	}
-	
-	public static void ColorsCheck(Gtk.CheckButton c) {
-		c.ModifyBg(StateType.Normal, WHITE);
-		c.ModifyBg(StateType.Active, BLUE);
-		c.ModifyBg(StateType.Prelight, BLUE_CLEAR);
+		if (tv.Selection.GetSelected (out model, out iter1)) {
+			store.Remove(ref iter1);
+		}
+		return store;
 	}
 
+	public static Gtk.TreeView RemoveColumns(Gtk.TreeView tv) {
+		Gtk.TreeViewColumn [] myColumns = tv.Columns;
+		foreach (Gtk.TreeViewColumn column in myColumns) {
+			tv.RemoveColumn (column);
+		}
+		return tv;
+	}
+
+
+
+	/*
+	 *
+	 * COLORS
+	 *
+	 */
+
+	/* howto find nice colors
+	 * open R
+	 * > colors()
+	 * if you like lightblue2 and red2 then:
+	 * > col2rgb(colors()[401])
+	 * > col2rgb(colors()[554])
+	 */
+	public static Gdk.Color WHITE = new Gdk.Color(0xff,0xff,0xff);
+	public static Gdk.Color BLACK = new Gdk.Color(0x00,0x00,0x00);
+	public static Gdk.Color BLUE = new Gdk.Color(0x6c,0x77,0xab);
+	public static Gdk.Color BLUE_CLEAR = new Gdk.Color(0xa0,0xa7,0xca);
+	
+	public static Gdk.Color RED_PLOTS = new Gdk.Color(238,0,0);
+	public static Gdk.Color LIGHT_BLUE_PLOTS = new Gdk.Color(178,223,238);
+	public static Gdk.Color BLUE_PLOTS = new Gdk.Color(0,0,238);
+	
+
+	public static void ColorsMenuLabel(Gtk.Viewport v, Gtk.Label l) {
+		l.ModifyFg(StateType.Active, v.Style.Foreground(StateType.Selected));
+		l.ModifyFg(StateType.Prelight, v.Style.Foreground(StateType.Selected));
+	}
+	
+	public static void ColorsTestLabel(Gtk.Viewport v, Gtk.Label l) {
+		l.ModifyFg(StateType.Active, v.Style.Foreground(StateType.Selected));
+		l.ModifyFg(StateType.Prelight, v.Style.Foreground(StateType.Selected));
+	}
+	
+	public static void ColorsRadio(Gtk.Viewport v, Gtk.RadioButton r) {
+		r.ModifyBg(StateType.Active, v.Style.Background(StateType.Selected));
+		r.ModifyBg(StateType.Prelight, v.Style.Background(StateType.Selected));
+	}
+	
 	public static void ColorsCheckOnlyPrelight(Gtk.CheckButton c) {
-		c.ModifyBg(StateType.Normal, WHITE);
-		c.ModifyBg(StateType.Active, WHITE);
-		c.ModifyBg(StateType.Prelight, BLUE_CLEAR);
+		//c.ModifyBg(StateType.Normal, WHITE);
+		//c.ModifyBg(StateType.Active, WHITE);
+		//c.ModifyBg(StateType.Prelight, BLUE_CLEAR);
+		
+		//c.ModifyBg(StateType.Active, c.Style.Background(StateType.Selected));
+		//c.ModifyBg(StateType.Prelight, c.Style.Background(StateType.Selected));
 	}
 
+	public static void ColorsTreeView(Gtk.Viewport v, Gtk.TreeView tv) {
+		tv.ModifyBg(StateType.Active, v.Style.Background(StateType.Selected));
+		tv.ModifyBg(StateType.Prelight, v.Style.Background(StateType.Selected));
+	}
+	
 
 	private static Gdk.Color chronopicViewportDefaultBg;
 	private static Gdk.Color chronopicLabelsDefaultFg;
 
 	public static void ChronopicColors(Gtk.Viewport v, Gtk.Label l1, Gtk.Label l2, bool connected) {
-		if(! v.Style.Background(StateType.Normal).Equal(BLUE))
+		//if(! v.Style.Background(StateType.Normal).Equal(BLUE))
+		if(! v.Style.Background(StateType.Normal).Equal(v.Style.Background(StateType.Selected)))
 			chronopicViewportDefaultBg = v.Style.Background(StateType.Normal);
 		if(! l1.Style.Foreground(StateType.Normal).Equal(WHITE))
 			chronopicLabelsDefaultFg = l1.Style.Foreground(StateType.Normal);
@@ -280,12 +288,57 @@ public class UtilGtk
 			l1.ModifyFg(StateType.Normal, chronopicLabelsDefaultFg);
 			l2.ModifyFg(StateType.Normal, chronopicLabelsDefaultFg);
 		} else {
-			v.ModifyBg(StateType.Normal, BLUE);
+			//v.ModifyBg(StateType.Normal, BLUE);
+			v.ModifyBg(StateType.Normal, v.Style.Background(StateType.Selected));
 			l1.ModifyFg(StateType.Normal, WHITE);
 			l2.ModifyFg(StateType.Normal, WHITE);
 		}
 	}
 
+	/*
+	 *
+	 * PRETTY THINGS
+	 *
+	 */
+
+	public static void ResizeIfNeeded(Gtk.Window win) {
+		int winX, winY;
+		win.GetSize(out winX, out winY);
+		int maxY = ScreenHeightFitted(true);
+		if(winY > maxY)
+			win.Resize(winX, maxY);
+	}
+
+	//(takes care)? of menu bar
+	public static int ScreenHeightFitted(bool fit) {
+		if(fit)
+			return ScreenHeight() -25;
+		else
+			return ScreenHeight();
+	}
+	
+	private static int ScreenHeight() {
+		//libmono-cairo2.0-cil
+		return Gdk.Display.Default.GetScreen(0).Height;
+	}
+	
+	public static int WidgetWidth(Gtk.Widget w) {
+		return w.Allocation.Width;
+	}
+	public static int WidgetHeight(Gtk.Widget w) {
+		return w.Allocation.Height;
+	}
+
+	public static void IconWindow(Gtk.Window myWindow) {
+		Gdk.Pixbuf chronojumpIcon = new Gdk.Pixbuf (null, Constants.FileNameIcon);
+            	myWindow.Icon = chronojumpIcon;
+	}
+
+	public static void IconWindowGraph(Gtk.Window myWindow) {
+		Gdk.Pixbuf chronojumpIcon = new Gdk.Pixbuf (null, Constants.FileNameIconGraph);
+            	myWindow.Icon = chronojumpIcon;
+	}
+
 
 	
 	public static TextBuffer TextViewPrint(string message) {
@@ -325,7 +378,13 @@ public class UtilGtk
 		l.TooltipText = Util.RemoveMarkup(s);
 	}
 
-	// -- drawingarea stuff
+
+	/*
+	 *
+	 * DRAWINGAREA
+	 *
+	 */
+
 	
 	public static void ErasePaint(Gtk.DrawingArea da, Gdk.Pixmap px) {
 		px.DrawRectangle (da.Style.WhiteGC, true, 0, 0, da.Allocation.Width, da.Allocation.Height);
@@ -343,7 +402,4 @@ public class UtilGtk
 	
 
 
-
-
-	// -- end of drawingarea stuff
 }
